//  Diffusion Client Library for iOS, tvOS and OS X / macOS
//
//  Copyright (c) 2015, 2017 Push Technology Ltd., All Rights Reserved.
//
//  Use is subject to license terms.
//
//  NOTICE: All information contained herein is, and remains the
//  property of Push Technology. The intellectual and technical
//  concepts contained herein are proprietary to Push Technology and
//  may be covered by U.S. and Foreign Patents, patents in process, and
//  are protected by trade secret or copyright law.

@import Foundation;

@class PTDiffusionRecordMetadata;

NS_ASSUME_NONNULL_BEGIN

/**
 @brief A record content schema describes a data item that can represent a collection of records.
 
 A record content schema object is immutable.
 
 @deprecated Since 6.0. Use PTDiffusionRecordV2 or PTDiffusionJSON.

 @since 5.6
 */
__deprecated_msg("Will be removed in a future release.")
@interface PTDiffusionRecordContentSchema : NSObject <NSCopying>

+(instancetype)new NS_UNAVAILABLE;

-(instancetype)init NS_UNAVAILABLE;

/**
 Returns a record content schema object initialized with the given record metadata array.

 @param recordMetadata The record metadata defining what records are expected as well as
 what order they should appear in. This array may not be empty.

 @exception NSInvalidArgumentException If any of the given record metadata is `nil` or empty.

 @since 5.6
 */
-(instancetype)initWithRecordMetadata:(NSArray<PTDiffusionRecordMetadata *> *)recordMetadata NS_DESIGNATED_INITIALIZER;

/**
 The name to give to schema.
 */
@property(nonatomic, readonly, copy) NSString* name;

/**
 The record metadata used to transform records using the receiver. This array may not be empty.

 @since 5.6
 */
@property(nonatomic, readonly, copy) NSArray<PTDiffusionRecordMetadata *> * recordMetadata; // of PTDiffusionRecordMetadata

/**
 Compares the receiver to the given record content schema.

 @param recordContentSchema The record content schema object with which to compare the receiver.

 @return `YES` if the record content schema is equal to the receiver, otherwise `NO`.

 @since 5.6
 */
-(BOOL)isEqualToRecordContentSchema:(nullable PTDiffusionRecordContentSchema *)recordContentSchema;

@end

NS_ASSUME_NONNULL_END
